pub fn ensure_tardis_deribit_deltas_parquet() -> PathBuf
Returns the path to the local Tardis Deribit BTC-PERPETUAL deltas Parquet file.
Panics if the file is missing, with the command to prepare test data.