ensure_test_data_exists

Function ensure_test_data_exists 

pub fn ensure_test_data_exists(filename: &str) -> PathBuf
Returns the path to a large test data file that is already present locally.

Panics

Panics if the file is missing, with the command to prepare test data.